pub struct Histogram {Show 13 fields
pub sum: f64,
pub schema: i32,
pub zero_threshold: f64,
pub negative_spans: Vec<BucketSpan>,
pub negative_deltas: Vec<i64>,
pub negative_counts: Vec<f64>,
pub positive_spans: Vec<BucketSpan>,
pub positive_deltas: Vec<i64>,
pub positive_counts: Vec<f64>,
pub reset_hint: i32,
pub timestamp: i64,
pub count: Option<Count>,
pub zero_count: Option<ZeroCount>,
}Expand description
A native histogram, also known as a sparse histogram. Original design doc: https://docs.google.com/document/d/1cLNv3aufPZb3fNfaJgdaRBZsInZKKIHo9E6HinJVbpM/edit The appendix of this design doc also explains the concept of float histograms. This Histogram message can represent both, the usual integer histogram as well as a float histogram.
Fields
sum: f64Sum of observations in the histogram.
schema: i32The schema defines the bucket schema. Currently, valid numbers are -4 <= n <= 8. They are all for base-2 bucket schemas, where 1 is a bucket boundary in each case, and then each power of two is divided into 2^n logarithmic buckets. Or in other words, each bucket boundary is the previous boundary times 2^(2^-n). In the future, more bucket schemas may be added using numbers < -4 or > 8.
zero_threshold: f64Breadth of the zero bucket.
negative_spans: Vec<BucketSpan>Negative Buckets.
negative_deltas: Vec<i64>Use either “negative_deltas” or “negative_counts”, the former for regular histograms with integer counts, the latter for float histograms.
Count delta of each bucket compared to previous one (or to zero for 1st bucket).
negative_counts: Vec<f64>Absolute count of each bucket.
positive_spans: Vec<BucketSpan>Positive Buckets.
positive_deltas: Vec<i64>Use either “positive_deltas” or “positive_counts”, the former for regular histograms with integer counts, the latter for float histograms.
Count delta of each bucket compared to previous one (or to zero for 1st bucket).
positive_counts: Vec<f64>Absolute count of each bucket.
reset_hint: i32timestamp: i64timestamp is in ms format, see model/timestamp/timestamp.go for conversion from time.Time to Prometheus timestamp.
count: Option<Count>Count of observations in the histogram.
zero_count: Option<ZeroCount>Count in zero bucket.
Implementations
Sourceimpl Histogram
impl Histogram
Sourcepub fn reset_hint(&self) -> ResetHint
pub fn reset_hint(&self) -> ResetHint
Returns the enum value of reset_hint, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reset_hint(&mut self, value: ResetHint)
pub fn set_reset_hint(&mut self, value: ResetHint)
Sets reset_hint to the provided enum value.