pub struct MetricMetadata {
pub type: i32,
pub metric_family_name: String,
pub help: String,
pub unit: String,
}Fields
type: i32Represents the metric type, these match the set from Prometheus. Refer to github.com/prometheus/common/model/metadata.go for details.
metric_family_name: Stringhelp: Stringunit: StringImplementations
Sourceimpl MetricMetadata
impl MetricMetadata
Sourcepub fn type(&self) -> MetricType
pub fn type(&self) -> MetricType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: MetricType)
pub fn set_type(&mut self, value: MetricType)
Sets type to the provided enum value.