pub struct ReadRequest {
pub queries: Vec<Query>,
pub accepted_response_types: Vec<i32>,
}Expand description
ReadRequest represents a remote read request.
Fields
queries: Vec<Query>accepted_response_types: Vec<i32>accepted_response_types allows negotiating the content type of the response.
Response types are taken from the list in the FIFO order. If no response type in accepted_response_types is
implemented by server, error is returned.
For request that do not contain accepted_response_types field the SAMPLES response type will be used.
Implementations
Sourceimpl ReadRequest
impl ReadRequest
Sourcepub fn accepted_response_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ResponseType>>
pub fn accepted_response_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ResponseType>>
Returns an iterator which yields the valid enum values contained in accepted_response_types.
Sourcepub fn push_accepted_response_types(&mut self, value: ResponseType)
pub fn push_accepted_response_types(&mut self, value: ResponseType)
Appends the provided enum value to accepted_response_types.